@@ -30,6 +30,8 @@ class DataDescriptionTest(unittest.TestCase):
             institution="AIND",
             data_level="raw data",
             funding_source=[f],
+            modality="exaSPIM",
+            subject_id="12345",
         )
         assert da.name == self.BASIC_NAME
 
@@ -56,7 +58,11 @@ class DataDescriptionTest(unittest.TestCase):
             )
 
         dd = DerivedDataDescription.from_name(
-            name=self.DERIVED_NAME, institution="AIND", funding_source=[f]
+            name=self.DERIVED_NAME,
+            institution="AIND",
+            funding_source=[f],
+            modality="SmartSPIM",
+            subject_id="12345",
         )
         assert dd.name == self.DERIVED_NAME
         assert dd.data_level.value == "derived data"
@@ -69,58 +75,105 @@ class DataDescriptionTest(unittest.TestCase):
                 funding_source=[f],
             )
 
+    def test_from_data_description(self):
+        """test the from_data_description method"""
+        dt = datetime.datetime.now()
+        d1 = RawDataDescription(
+            creation_date=dt.date(),
+            creation_time=dt.time(),
+            institution="AIND",
+            data_level="raw data",
+            funding_source=[],
+            modality="ecephys",
+            subject_id="12345",
+        )
+
+        dt = datetime.datetime.now()
+        d2 = DerivedDataDescription.from_data_description(
+            input_data=d1,
+            process_name="fishing",
+            creation_date=dt.date(),
+            creation_time=dt.time(),
+            institution="AIND",
+            funding_source=[],
+        )
+
+        assert d2.modality == d1.modality
+        assert d2.subject_id == d1.subject_id
+
+        d3 = DerivedDataDescription.from_data_description(
+            input_data=d2,
+            process_name="bailing",
+            creation_date=dt.date(),
+            creation_time=dt.time(),
+            institution="HUST",
+            funding_source=[],
+        )
+
+        assert d3.modality == d2.modality
+        assert d3.subject_id == d2.subject_id
+
     def test_constructors(self):
         """test building from component parts"""
         f = Funding(funder="test")
 
         dt = datetime.datetime.now()
-        da = DataDescription(
-            label="ecephys_1234",
+        da = RawDataDescription(
             creation_date=dt.date(),
             creation_time=dt.time(),
             institution="AIND",
             data_level="raw data",
             funding_source=[f],
+            modality="ecephys",
+            subject_id="12345",
         )
 
         r1 = DerivedDataDescription(
-            input_data=da,
+            input_data_name=da.name,
             process_name="spikesort-ks25",
             creation_date=dt.date(),
             creation_time=dt.time(),
             institution="AIND",
             funding_source=[f],
+            modality=da.modality,
+            subject_id=da.subject_id,
         )
 
         r2 = DerivedDataDescription(
-            input_data=r1,
+            input_data_name=r1.name,
             process_name="some-model",
             creation_date=dt.date(),
             creation_time=dt.time(),
             institution="AIND",
             funding_source=[f],
+            modality="ecephys",
+            subject_id="12345",
         )
 
         r3 = DerivedDataDescription(
-            input_data=r2,
+            input_data_name=r2.name,
             process_name="a-paper",
             creation_date=dt.date(),
             creation_time=dt.time(),
             institution="AIND",
             funding_source=[f],
+            modality="ecephys",
+            subject_id="12345",
         )
         assert r3 is not None
 
-        ad = RawDataDescription(
+        dd = DataDescription(
+            label="test_data",
             modality="ecephys",
             subject_id="1234",
+            data_level="raw data",
             creation_date=dt.date(),
             creation_time=dt.time(),
             institution="AIND",
             funding_source=[f],
         )
 
-        assert ad is not None
+        assert dd is not None
 
 
 if __name__ == "__main__":
